<?php namespace RVR\Repository;

use DateTime;
use Generator;
use SokoWeb\Database\Query\Select;
use RVR\PersistentData\Model\OAuthToken;
use RVR\PersistentData\Model\OAuthSession;

class OAuthTokenRepository
{
    public function getById(int $id): ?OAuthToken
    {
        return \Container::$persistentDataManager->selectFromDbById($id, OAuthToken::class);
    }

    public function getAllBySession(OAuthSession $session, bool $useRelations = false, array $withRelations = []): Generator
    {
        $select = $this->selectAllBySession($session);

        yield from \Container::$persistentDataManager->selectMultipleFromDb($select, OAuthToken::class, $useRelations, $withRelations);
    }

    public function countAllBySession(OAuthSession $session): int
    {
        return $this->selectAllBySession($session)->count();
    }

    public function getAllExpired(): Generator
    {
        $select = new Select(\Container::$dbConnection);
        $select->where('expires', '<', (new DateTime())->format('Y-m-d H:i:s'));

        yield from \Container::$persistentDataManager->selectMultipleFromDb($select, OAuthToken::class);
    }

    private function selectAllBySession(OAuthSession $session): Select
    {
        $select = new Select(\Container::$dbConnection, OAuthToken::getTable());
        $select->where('session_id', '=', $session->getId());
        return $select;
    }
}
